/*
	FILE		: PeregrineInVivo.h
	DESCRIPTION	: Peregrine in vivo API for Java providing:
					1: Peregrine Test Probes for automated in vivo testing of (embedded) software.
					2: Interprocess communication between the Peregrine program (Tester) and the program under test (Testee).
	COPYRIGHT	: (c) 2017-2023 Fluxica Computer Engineering
	CONTACT		: info@fluxica.com
*/

/* 
	A test is set up in four steps:

    1. Include this header file.
    2. Add two Peregrine code delimiters around the code segment to be tested.
    3. Replace (selected) variables with matching Peregrine Test Probe types in the marked out code segment.
    4. Preprocess and compile the program source code to create a class file.

	Invoking the Peregrine program and then running the class file will automatically test the code segment. For more 
	information, please see the Fluxica Peregrine Reference Manual.
*/

/* 
	PEREGRINE IN VIVO JAVA NATIVE INTERFACE PACKAGE
*/

import peregrinejava.PeregrineInVivo;

/* 
	MACRO DEFINITIONS PEREGRINE IN VIVO CODE DELIMITERS 
*/

#define PEREGRINE_RED_CLIP PeregrineInVivo PDT=new PeregrineInVivo(); PDT.constructor(); while(PDT.flag()) {
#define PEREGRINE_BLACK_CLIP } PDT.destructor(); 

/* 
	MACRO DEFINITION PEREGRINE IN VIVO FAILURE DETECTED
*/

#define PEREGRINE_ORACLE PDT.oracle()

/*	
	MACRO DEFINITIONS PEREGRINE IN VIVO TEST PROBES

	The semicolon after the Peregrine Test Probe (PTP) is provided by the calling
	program (Testee) if required, making both variable assignment and variable 
	passing possible for PTPs.

	The trailing number of a PTP defines the number of bits that are actually used, 
	the address space in memory is always at least 8 bits wide.

	A PTP is not similar or equivalent to a Java data type. A PTP provides a value of 
	a given type that will have changed its value before it is read again. The next 
	value does not depend on previous values. The values have a uniform (pseudo-)random 
	distribution, they are in every practical sense without any bias.
*/

#define LONG 		PDT.LONG()
#define DOUBLE		PDT.DOUBLE()
#define INT			PDT.INT()
#define FLOAT		PDT.FLOAT()
#define SHORT		PDT.SHORT()
#define CHAR		PDT.CHAR()
#define BOOLEAN		PDT.BOOLEAN()
#define BYTE		PDT.BYTE()

#define	UINT64		PDT.UINT64()
#define	INT64		PDT.INT64()
#define	UINT32		PDT.UINT32()
#define	INT32		PDT.INT32()
#define	UINT16		PDT.UINT16()
#define	INT16		PDT.INT16()
#define	UINT8		PDT.UINT8()
#define	INT8		PDT.INT8()
#define	UINT4		PDT.UINT4()
#define	INT4		PDT.INT4()
#define	UINT2		PDT.UINT2()
#define	INT2		PDT.INT2()    
#define	UINT1		PDT.UINT1()
#define	BOOL1		PDT.BOOL1()    
#define	UCHAR8		PDT.UCHAR8()
#define	CHAR8		PDT.CHAR8()
#define	FLOAT32		PDT.FLOAT32()
#define	DOUBLE64	PDT.DOUBLE64()
