#!/bin/bash

#	FILE		: peregrine_auto.sh
#	DESCRIPTION	: Bash command line interface script to install/uninstall the Peregrine archive file.
#	COPYRIGHT	: (c) 2017-2023 Fluxica Computer Engineering
#	CONTACT		: info@fluxica.com

#	SYNOPSIS	:	First extract the script file:
#						1: tar -xf peregrine_<version>.tar.gz ./peregrine_auto.sh  
#						2: or double-click the archive file and drag-drop peregrine_auto.sh to the directory where the archive file is located.
#					To run the peregrine_auto script file:
#						1: ./peregrine_auto.sh
#						2: or double-click the script file.

PEREGRINE_ARCHIVE=peregrine_demo.tar.gz
PEREGRINE_DIRECTORY=$HOME/peregrine
 
printf "\033c"

echo -e "Bash shell script to install/uninstall the Fluxica Peregrine archive file.\n"
echo -e " i - Install the Peregrine archive file."
echo -e " u - Uninstall the Peregrine archive file."
echo -e " e - Exit without performing any operation.\n"

read -p "Please select an option and press Enter [i/u/e]: " ACTION

echo ""

if [[ $ACTION = 'i' ]]; then
	if [[ -f $PEREGRINE_ARCHIVE ]]; then
	
		IS_DIR=false
		
		if [[ ! -d $PEREGRINE_DIRECTORY ]]; then
			mkdir $PEREGRINE_DIRECTORY
			IS_DIR=true
			echo -e "- Created directory: $PEREGRINE_DIRECTORY"
		else
			IS_DIR=true
			read -p $"- Directory $PEREGRINE_DIRECTORY already exists. Continue [y/n]? " CONFIRM
			if [[ $CONFIRM != "y" ]]; then					
				echo -e "- Archive file $PEREGRINE_ARCHIVE not installed."
				IS_DIR=false
			fi
		fi

		if [[ "$IS_DIR" = true ]]; then
			tar -xf $PEREGRINE_ARCHIVE -C $PEREGRINE_DIRECTORY
			echo -e "- Installed $PEREGRINE_ARCHIVE archive file in: $PEREGRINE_DIRECTORY"
			
			if [[ ! -L "/usr/bin/peregrine" ]]; then
		    	echo "- Superuser privileges required to create symbolic links."
				sudo ln -s $HOME/peregrine/peregrine /usr/bin/peregrine
				echo -e "- Created symbolic link: /usr/bin/peregrine"
			fi

			if [[ ! -L "/usr/bin/peregrine_gui" ]]; then
				sudo ln -s $HOME/peregrine/peregrine_gui /usr/bin/peregrine_gui
				echo -e "- Created symbolic link: /usr/bin/peregrine_gui"	
			fi

			if [[ ! -L "/usr/include/peregrine_in_vivo.h" ]]; then			
				sudo ln -s $HOME/peregrine/c_cpp/peregrine_in_vivo.h /usr/include/peregrine_in_vivo.h
				echo -e "- Created symbolic link: /usr/include/peregrine_in_vivo.h"
			fi

			if [[ ! -L "/usr/lib/libperegrine.a" ]]; then			
				sudo ln -s $HOME/peregrine/c_cpp/libperegrine.a /usr/lib/libperegrine.a
				echo -e "- Created symbolic link: /usr/lib/libperegrine.a"	
			fi
		
			if [[ ! -L "/usr/include/PeregrineInVivo.h" ]]; then			
				sudo ln -s $HOME/peregrine/peregrinejava/PeregrineInVivo.h /usr/include/PeregrineInVivo.h
				echo -e "- Created symbolic link: /usr/include/PeregrineInVivo.h"
			fi

			if [[ ! -L "/usr/bin/cppjava" ]]; then
				sudo ln -s $HOME/peregrine/peregrinejava/cppjava.sh /usr/bin/cppjava
				echo -e "- Created symbolic link: /usr/bin/cppjava"
			fi
		fi	
	else
		echo -e "- Archive file $PEREGRINE_ARCHIVE not available in current directory."
	fi
elif [[ $ACTION = 'u' ]]; then
	if [[ -d $PEREGRINE_DIRECTORY ]]; then		
		read -p $"- Remove $PEREGRINE_DIRECTORY directory and subdirectories [y/n]? " CONFIRM
		if [[ $CONFIRM = "y" ]]; then
			if [[ -L "/usr/bin/peregrine" ]]; then
	    		echo "- Superuser privileges required to remove symbolic links."
				sudo rm /usr/bin/peregrine
				echo -e "- Removed symbolic link: /usr/bin/peregrine"
			fi

			if [[ -L "/usr/bin/peregrine_gui" ]]; then
				sudo rm /usr/bin/peregrine_gui
				echo -e "- Removed symbolic link: /usr/bin/peregrine_gui"
			fi

			if [[ -L "/usr/include/peregrine_in_vivo.h" ]]; then			
				sudo rm /usr/include/peregrine_in_vivo.h
				echo -e "- Removed symbolic link: /usr/include/peregrine_in_vivo.h"	
			fi
	
			if [[ -L "/usr/lib/libperegrine.a" ]]; then			
				sudo rm /usr/lib/libperegrine.a
				echo -e "- Removed symbolic link: /usr/lib/libperegrine.a"
			fi
					
			if [[ -L "/usr/include/PeregrineInVivo.h" ]]; then			
				sudo rm /usr/include/PeregrineInVivo.h
				echo -e "- Removed symbolic link: /usr/include/PeregrineInVivo.h"
			fi

			if [[ -L "/usr/bin/cppjava" ]]; then
				sudo rm /usr/bin/cppjava
				echo -e "- Removed symbolic link: /usr/bin/cppjava"
			fi
			
			rm -r $PEREGRINE_DIRECTORY
			echo -e "- Removed directory: $PEREGRINE_DIRECTORY"
		else 
			echo -e "- Directory $PEREGRINE_DIRECTORY not removed."
		fi		
	else	
		echo -e "- Directory $PEREGRINE_DIRECTORY does not exist."
	fi
elif [[ $ACTION = 'e' ]]; then
	echo -e "- No operation performed."
else 
	echo -e "- Input is either i, u or e."
fi

echo -ne "\nPress Enter to close this script session."
read enter
exit
